@@ -1,5 +1,5 @@
 from .version import __version__
-from .logs import log_and_message, message
+from .logs import log_and_message, message, initiate_logger
 
 import PyFBA.Biochemistry
 import PyFBA.fba
@@ -11,7 +11,7 @@ import PyFBA.model_seed
 import PyFBA.parse
 
 all = [
-    '__version__', 'logger', 'log_and_message', 'message', 'MODELSEED_DIR'
+    '__version__', 'logger', 'log_and_message', 'message', 'MODELSEED_DIR', 'initiate_logger'
     ]
 
 
