@@ -29,64 +29,6 @@ def run_eqn(why, md, r2r, med, bme, verbose=False):
     return value, growth
 
 
-def minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation, verbose=False):
-    """
-    Sort thorugh all the added reactions and return a dict of new reactions
-    :param original_reactions_to_run: the original set from our genome
-    :type original_reactions_to_run: set(PyFBA.metabolism.Reaction)
-    :param added_reactions: new reactions we need
-    :type added_reactions: list[(str, set(str)]
-    :param modeldata: our modeldata object
-    :type modeldata: PyFBA.model_seed.ModelData
-    :param media: our media object
-    :type media: set[PyFBA.metabolism.Compound]
-    :param biomass_equation: our biomass equation
-    :type biomass_equation: PyFBA.metabolism.Reaction
-    :param verbose: more output
-    :type verbose: bool
-    :return: A dict of the minimal set of reactions and their source
-    :rtype: dict[str, str]
-    """
-    reqd_additional = set()
-    print(f"Before we began, we had {len(original_reactions_to_run)} reactions")
-
-    rxn_source = {}
-
-    while added_reactions:
-        ori = copy.deepcopy(original_reactions_to_run)
-        ori.update(reqd_additional)
-        # Test next set of gap-filled reactions
-        # Each set is based on a method described above
-        how, new = added_reactions.pop()
-        sys.stderr.write(f"Testing reactions from {how}\n")
-
-        # Get all the other gap-filled reactions we need to add
-        for tple in added_reactions:
-            ori.update(tple[1])
-
-        for r in new:
-            # remember the source. It doesn't matter if we overwrite, as it will replace later with earlier
-            rxn_source[r] = how
-
-        # Use minimization function to determine the minimal
-        # set of gap-filled reactions from the current method
-        new_essential = PyFBA.gapfill.minimize_additional_reactions(ori, new, modeldata, media, biomass_equation,
-                                                                    verbose=True)
-        log_and_message(f"Saved {len(new_essential)} reactions from {how}", stderr=verbose)
-        # Record the method used to determine
-        # how the reaction was gap-filled
-        for new_r in new_essential:
-            modeldata.reactions[new_r].is_gapfilled = True
-            modeldata.reactions[new_r].gapfill_method = how
-        reqd_additional.update(new_essential)
-
-    # add the original set too
-    for r in original_reactions_to_run:
-        rxn_source[r] = 'genome prediction'
-
-    # Combine old and new reactions and add the source, to return a dict
-    return {r: rxn_source[r] for r in original_reactions_to_run.union(reqd_additional)}
-
 
 def roles_to_reactions_to_run(roles, orgtype='gramnegative', verbose=False):
     roles_to_reactions = PyFBA.filters.roles_to_reactions(roles, organism_type=orgtype, verbose=verbose)
@@ -97,34 +39,6 @@ def roles_to_reactions_to_run(roles, orgtype='gramnegative', verbose=False):
     return reactions_to_run
 
 
-def read_media(mediafile, modeldata, verbose=False):
-    """
-    Read the media file and return a set of compounds
-    :param modeldata: the modeldata object
-    :type modeldata: PyFBA.model_seed.ModelData
-    :param mediafile: the media file to read
-    :param verbose: more output
-    :type verbose: bool
-    :return: a set of media compounds
-    :rtype: Set[PyFBA.metabolism.Compound]
-    """
-
-    if mediafile in PyFBA.parse.media_files():
-        log_and_message(f"parsing media directly from {mediafile}", stderr=verbose)
-        # pyfba media already corrects the names, so we can  just return it.
-        return PyFBA.parse.pyfba_media(mediafile, modeldata)
-    elif os.path.exists(mediafile):
-        log_and_message(f"parsing media file {mediafile}", stderr=verbose)
-        media = PyFBA.parse.read_media_file(mediafile)
-    elif 'PYFBA_MEDIA_DIR' in os.environ and os.path.exists(os.path.join(os.environ['PYFBA_MEDIA_DIR'], mediafile)):
-        log_and_message(f"parsing media file {os.path.join(os.environ['PYFBA_MEDIA_DIR'], mediafile)}", stderr=verbose)
-        media = PyFBA.parse.read_media_file(os.path.join(os.environ['PYFBA_MEDIA_DIR'], mediafile))
-    else:
-        log_and_message(f"Can't figure out how to parse media from {mediafile}", stderr=True, loglevel="CRITICAL")
-        sys.exit(-1)
-    return PyFBA.parse.correct_media_names(media, modeldata.compounds)
-
-
 def update_r2r(old, new, why, verbose=False):
     """
     Update the reactions to run and log the changes
@@ -208,8 +122,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
     value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
     if growth:
-        return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                  verbose=verbose)
+        return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                biomass_equation, verbose=verbose)
 
     #############################################################################################
     #                                       LINKED REACTIONS                                    #
@@ -224,8 +138,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
     value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
     if growth:
-        return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                  verbose=verbose)
+        return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                biomass_equation, verbose=verbose)
 
     #############################################################################################
     #                                       EC NUMBERS                                          #
@@ -240,8 +154,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
     value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
     if growth:
-        return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                  verbose=verbose)
+        return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                biomass_equation, verbose=verbose)
 
     #############################################################################################
     #                                       Media import reactions                              #
@@ -254,8 +168,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
     value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
     if growth:
-        return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                  verbose=verbose)
+        return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                biomass_equation, verbose=verbose)
 
     #############################################################################################
     #                                        Other genomes and organisms                        #
@@ -272,8 +186,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
         value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
         if growth:
-            return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                      verbose=verbose)
+            return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                    biomass_equation, verbose=verbose)
 
     if close_genera:
         # add reactions from roles in similar genera
@@ -285,8 +199,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
         value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
         if growth:
-            return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                      verbose=verbose)
+            return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                    biomass_equation, verbose=verbose)
 
     #############################################################################################
     #                                        Subsystems                                         #
@@ -301,8 +215,9 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
     value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
     if growth:
-        return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                  verbose=verbose)
+        return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                biomass_equation, verbose=verbose)
+
     #############################################################################################
     #                                        Orphan compounds                                   #
     #############################################################################################
@@ -314,8 +229,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
     value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
     if growth:
-        return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                  verbose=verbose)
+        return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                biomass_equation, verbose=verbose)
 
     # ## Revisit EC Numbers
     #
@@ -335,8 +250,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
     value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
     if growth:
-        return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                  verbose=verbose)
+        return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                biomass_equation, verbose=verbose)
 
     # We revist linked reactions once more, because now we have many more reactions in our set to run!
 
@@ -353,8 +268,8 @@ def run_gapfill_from_roles(roles, reactions_to_run, modeldata, media, orgtype='g
     value, growth = run_eqn("Initial", modeldata, reactions_to_run, media, biomass_equation, verbose=verbose)
 
     if growth:
-        return minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media, biomass_equation,
-                                  verbose=verbose)
+        return PyFBA.gapfill.minimize_reactions(original_reactions_to_run, added_reactions, modeldata, media,
+                                                biomass_equation, verbose=verbose)
 
     log_and_message(f"FATAL: After compiling {len(reactions_to_run)} reactions, we still could not get growth",
                     stderr=True, loglevel='CRITICAL')
@@ -408,7 +323,7 @@ def gapfill_from_roles():
         sys.exit(1)
 
     reactions_to_run = roles_to_reactions_to_run(roles, args.type, args.verbose)
-    media = read_media(args.media, model_data, args.verbose)
+    media = PyFBA.parse.read_media.find_media_file(args.media, model_data, args.verbose)
 
     new_reactions = run_gapfill_from_roles(roles=roles, reactions_to_run=reactions_to_run, modeldata=model_data,
                                            media=media, orgtype=args.type, close_orgs=args.close,
