@@ -1,4 +1,4 @@
-from .read_media import read_media_file, pyfba_media, media_files, correct_media_names, raw_media
+from .read_media import read_media_file, pyfba_media, media_files, correct_media_names, raw_media, find_media_file
 from .rast import read_assigned_functions, roles_of_function, roles_to_subsystem
 from .rast import read_functional_roles, read_features_file, assigned_functions_set
 from .model_seed import compounds_reactions_enzymes, parse_model_seed_data
